==> mbegroup-employer-v1.2.0-0a5567.zip: lang/pl/filament.php <==
<?php

return [
    'resources' => [
        'employer' => [
            'navigation_label'   => 'Pracodawcy',
            'model_label'        => 'Pracodawca',
            'plural_model_label' => 'Pracodawcy',
            'table'              => [
                'columns' => [
                    'name'       => 'Nazwa',
                    'slug'       => 'Slug',
                    'status'     => 'Status',
                    'created_at' => 'Utworzono',
                    'updated_at' => 'Zaktualizowano',
                ],
            ],
            'form' => [
                'fields' => [
                    'name'                               => 'Nazwa',
                    'slug'                               => 'Slug',
                    'industry'                           => 'Branża',
                    'company_size'                       => 'Wielkość firmy',
                    'company_type'                       => 'Typ firmy',
                    'logo'                               => 'Logo',
                    'cover_image'                        => 'Zdjęcie w tle',
                    'account_manager_id'                 => 'Opiekun klienta',
                    'status'                             => 'Status',
                    'products'                           => 'Produkty',
                    'products_placeholder'               => 'Wybierz produkty...',
                    'product'                            => 'Produkt',
                    'quantity'                           => 'Ilość',
                    'product_name'                       => 'Nazwa produktu',
                    'unit'                               => 'Jednostka',
                    'add_product'                        => 'Dodaj produkt',
                    'remove_product'                     => 'Usuń produkt',
                    'locations'                          => 'Lokalizacje',
                    'add_location'                       => 'Dodaj lokalizację',
                    'email'                              => 'Email',
                    'phone'                              => 'Telefon',
                    'website'                            => 'Strona internetowa',
                    'fv_name'                            => 'Nazwa prawna firmy',
                    'fv_nip'                             => 'NIP',
                    'fv_address'                         => 'Adres',
                    'job_offer_template'                 => 'Szablon oferty pracy',
                    'add_job_offer_template'             => 'Dodaj szablon',
                    'remove_job_offer_template'          => 'Usuń szablon',
                    'job_offer_template_name'            => 'Nazwa szablonu',
                    'job_offer_template_html'            => 'HTML szablonu',
                    'job_offer_template_css'             => 'CSS szablonu',
                    'job_offer_is_default_template'      => 'Ustaw jako domyślny',
                    'job_offer_template_variables'       => 'Zmienne szablonu',
                    'google_search'                      => 'Wyszukiwanie Google',
                    'location_name'                      => 'Nazwa lokalizacji',
                    'municipality'                       => 'Gmina',
                    'postal_code'                        => 'Kod pocztowy',
                    'street'                             => 'Ulica',
                    'building_number'                    => 'Numer budynku',
                    'apartment_number'                   => 'Numer mieszkania',
                    'country'                            => 'Kraj',
                    'latitude'                           => 'Szerokość geograficzna',
                    'longitude'                          => 'Długość geograficzna',
                    'region'                             => 'Województwo',
                    'add_variable'                       => 'Dodaj zmienną',
                    'variable_name'                      => 'Nazwa zmiennej',
                    'variable_type'                      => 'Typ zmiennej',
                    'location_is_default'                => 'Ustaw jako domyślną',
                    'seo_title'                          => 'Tytuł SEO',
                    'seo_description'                    => 'Opis SEO',
                    'seo_keywords'                       => 'Słowa kluczowe SEO',
                    'seo_noindex'                        => 'Noindex',
                    'job_offer_refresh_frequency'        => 'Częstotliwość odświeżeń - co ile dni odświeżane jest ogłoszenie',
                    'job_offer_refresh_frequency_update' => 'Aktualizuj częstotliwość odświeżeń w ofertach',
                    'application_method'                 => 'Domyślny sposób aplikacji',
                    'application_link_reference'         => 'Parametr referencji linku aplikacji',
                    'application_link_reference_value'   => 'Wartość parametru referencji linku aplikacji',
                    'application_remote_recruitment'     => 'Rekrutacja zdalna',
                    'application_email'                  => 'Adres email',
                ],
                'tabs' => [
                    'basic_info'           => 'Informacje podstawowe',
                    'products'             => 'Aktywne produkty',
                    'location_and_contact' => 'Lokalizacja i kontakt',
                    'fv_info'              => 'Dane do faktury',
                    'job_offer_template'   => 'Szablon oferty pracy',
                    'publication_settings' => 'Ustawienia publikacji',
                    'apply_options'        => 'Sposób aplikacji',
                    'job_offers_refresh'   => 'Odświeżanie ofert pracy',
                    'seo'                  => 'SEO',
                ],
                'description' => [
                    'saveAndBack' => 'Zapisz i wróć do listy pracodawców',
                ],
            ],
        ],
    ],
    'navigation' => [
        'group' => [
            'label' => 'Pracodawcy',
        ],
    ],
];

==> mbegroup-employer-v1.4.0-b6a073.zip: lang/pl/filament.php <==
<?php

return [
    'resources' => [
        'employer' => [
            'navigation_label'   => 'Pracodawcy',
            'model_label'        => 'Pracodawca',
            'plural_model_label' => 'Pracodawcy',
            'table'              => [
                'columns' => [
                    'name'       => 'Nazwa',
                    'slug'       => 'Slug',
                    'status'     => 'Status',
                    'created_at' => 'Utworzono',
                    'updated_at' => 'Zaktualizowano',
                ],
            ],
            'form' => [
                'fields' => [
                    'name'                               => 'Nazwa',
                    'slug'                               => 'Slug',
                    'industry'                           => 'Branża',
                    'company_size'                       => 'Wielkość firmy',
                    'company_type'                       => 'Typ firmy',
                    'logo'                               => 'Logo',
                    'cover_image'                        => 'Zdjęcie w tle',
                    'account_manager_id'                 => 'Opiekun klienta',
                    'status'                             => 'Status',
                    'products'                           => 'Produkty',
                    'products_placeholder'               => 'Wybierz produkty...',
                    'product'                            => 'Produkt',
                    'quantity'                           => 'Ilość',
                    'product_name'                       => 'Nazwa produktu',
                    'validity_period_start'              => 'Okres ważności - start',
                    'validity_period_end'                => 'Okres ważności - koniec',
                    'add_product'                        => 'Dodaj produkt',
                    'remove_product'                     => 'Usuń produkt',
                    'locations'                          => 'Lokalizacje',
                    'add_location'                       => 'Dodaj lokalizację',
                    'email'                              => 'Email',
                    'phone'                              => 'Telefon',
                    'website'                            => 'Strona internetowa',
                    'fv_name'                            => 'Nazwa prawna firmy',
                    'fv_nip'                             => 'NIP',
                    'fv_address'                         => 'Adres',
                    'job_offer_template'                 => 'Szablon oferty pracy',
                    'add_job_offer_template'             => 'Dodaj szablon',
                    'remove_job_offer_template'          => 'Usuń szablon',
                    'job_offer_template_name'            => 'Nazwa szablonu',
                    'job_offer_template_html'            => 'HTML szablonu',
                    'job_offer_template_css'             => 'CSS szablonu',
                    'job_offer_is_default_template'      => 'Ustaw jako domyślny',
                    'job_offer_template_variables'       => 'Zmienne szablonu',
                    'google_search'                      => 'Wyszukiwanie Google',
                    'location_name'                      => 'Nazwa lokalizacji',
                    'municipality'                       => 'Gmina',
                    'postal_code'                        => 'Kod pocztowy',
                    'street'                             => 'Ulica',
                    'building_number'                    => 'Numer budynku',
                    'apartment_number'                   => 'Numer mieszkania',
                    'country'                            => 'Kraj',
                    'latitude'                           => 'Szerokość geograficzna',
                    'longitude'                          => 'Długość geograficzna',
                    'region'                             => 'Województwo',
                    'add_variable'                       => 'Dodaj zmienną',
                    'variable_name'                      => 'Nazwa zmiennej',
                    'variable_type'                      => 'Typ zmiennej',
                    'location_is_default'                => 'Ustaw jako domyślną',
                    'seo_title'                          => 'Tytuł SEO',
                    'seo_description'                    => 'Opis SEO',
                    'seo_keywords'                       => 'Słowa kluczowe SEO',
                    'seo_noindex'                        => 'Noindex',
                    'job_offer_refresh_frequency'        => 'Częstotliwość odświeżeń - co ile dni odświeżane jest ogłoszenie',
                    'job_offer_refresh_frequency_update' => 'Aktualizuj częstotliwość odświeżeń w ofertach',
                    'application_method'                 => 'Domyślny sposób aplikacji',
                    'application_link_reference'         => 'Parametr referencji linku aplikacji',
                    'application_link_reference_value'   => 'Wartość parametru referencji linku aplikacji',
                    'application_remote_recruitment'     => 'Rekrutacja zdalna',
                    'application_email'                  => 'Adres email',
                ],
                'tabs' => [
                    'basic_info'           => 'Informacje podstawowe',
                    'products'             => 'Aktywne produkty',
                    'location_and_contact' => 'Lokalizacja i kontakt',
                    'fv_info'              => 'Dane do faktury',
                    'job_offer_template'   => 'Szablon oferty pracy',
                    'publication_settings' => 'Ustawienia publikacji',
                    'apply_options'        => 'Sposób aplikacji',
                    'job_offers_refresh'   => 'Odświeżanie ofert pracy',
                    'seo'                  => 'SEO',
                ],
                'description' => [
                    'saveAndBack' => 'Zapisz i wróć do listy pracodawców',
                ],
            ],
        ],
    ],
    'navigation' => [
        'group' => [
            'label' => 'Pracodawcy',
        ],
    ],
];
